# Wrap

Wrap atoms into the unit cell using [`MDAnalysis.transformations.wrap.wrap`](https://docs.mdanalysis.org/stable/documentation_pages/transformations/wrap.html#MDAnalysis.transformations.wrap.wrap).

<video controls>
  <source src="../../movies/mda-tui-wrap.mp4" type="video/mp4">
</video>
